@@ -12,7 +12,7 @@ use English qw( -no_match_vars );
 use DirHandle();
 use POSIX();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -66,7 +66,7 @@ sub _DEFAULT_DST_START_HOUR                { return 2 }
 sub _DEFAULT_DST_END_HOUR                  { return 2 }
 
 sub _TIMEZONE_FULL_NAME_REGEX {
-    return qr/(?<area>\w+)(?:\/(?<location>[\w\-\/]+))?/smx;
+    return qr/(?<area>\w+)(?:\/(?<location>[\w\-\/+]+))?/smx;
 }
 
 my $_default_zoneinfo_directory = '/usr/share/zoneinfo';
@@ -1255,7 +1255,7 @@ sub _read_tz_definition {
 sub _parse_tz_variable {
     my ( $self, $tz_variable, $path ) = @_;
     my $timezone_abbr_name_regex =
-      qr/(?:[^:\d,+-][^\d,+-]{2,}|[<][+-]?\d+[>])/smx;
+      qr/(?:[^:\d,+-][^\d,+-]{2,}|[<]\w*[+-]?\d+[>])/smx;
     my $std_name_regex = qr/(?<std_name>$timezone_abbr_name_regex)/smx
       ;    # Name for standard offset from GMT
     my $std_sign_regex    = qr/(?<std_sign>[+-])/smx;
@@ -1550,7 +1550,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
